==> huaweicloudsdkkafka-3.1.48-py2.py3-none-any.whl: huaweicloudsdkkafka/v2/model/delete_sink_task_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteSinkTaskRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'connector_id': 'str',
        'task_id': 'str'
    }

    attribute_map = {
        'connector_id': 'connector_id',
        'task_id': 'task_id'
    }

    def __init__(self, connector_id=None, task_id=None):
        """DeleteSinkTaskRequest

        The model defined in huaweicloud sdk

        :param connector_id: 实例转储ID。 请参考[实例生命周期][查询实例]接口返回的数据。
        :type connector_id: str
        :param task_id: 转储任务ID。
        :type task_id: str
        """
        
        

        self._connector_id = None
        self._task_id = None
        self.discriminator = None

        self.connector_id = connector_id
        self.task_id = task_id

    @property
    def connector_id(self):
        """Gets the connector_id of this DeleteSinkTaskRequest.

        实例转储ID。 请参考[实例生命周期][查询实例]接口返回的数据。

        :return: The connector_id of this DeleteSinkTaskRequest.
        :rtype: str
        """
        return self._connector_id

    @connector_id.setter
    def connector_id(self, connector_id):
        """Sets the connector_id of this DeleteSinkTaskRequest.

        实例转储ID。 请参考[实例生命周期][查询实例]接口返回的数据。

        :param connector_id: The connector_id of this DeleteSinkTaskRequest.
        :type connector_id: str
        """
        self._connector_id = connector_id

    @property
    def task_id(self):
        """Gets the task_id of this DeleteSinkTaskRequest.

        转储任务ID。

        :return: The task_id of this DeleteSinkTaskRequest.
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this DeleteSinkTaskRequest.

        转储任务ID。

        :param task_id: The task_id of this DeleteSinkTaskRequest.
        :type task_id: str
        """
        self._task_id = task_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteSinkTaskRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkkafka-3.1.74-py2.py3-none-any.whl: huaweicloudsdkkafka/v2/model/delete_sink_task_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteSinkTaskRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'connector_id': 'str',
        'task_id': 'str'
    }

    attribute_map = {
        'connector_id': 'connector_id',
        'task_id': 'task_id'
    }

    def __init__(self, connector_id=None, task_id=None):
        """DeleteSinkTaskRequest

        The model defined in huaweicloud sdk

        :param connector_id: 实例转储ID。  请参考[查询实例](ShowInstance.xml)返回的数据。
        :type connector_id: str
        :param task_id: 转储任务ID。
        :type task_id: str
        """
        
        

        self._connector_id = None
        self._task_id = None
        self.discriminator = None

        self.connector_id = connector_id
        self.task_id = task_id

    @property
    def connector_id(self):
        """Gets the connector_id of this DeleteSinkTaskRequest.

        实例转储ID。  请参考[查询实例](ShowInstance.xml)返回的数据。

        :return: The connector_id of this DeleteSinkTaskRequest.
        :rtype: str
        """
        return self._connector_id

    @connector_id.setter
    def connector_id(self, connector_id):
        """Sets the connector_id of this DeleteSinkTaskRequest.

        实例转储ID。  请参考[查询实例](ShowInstance.xml)返回的数据。

        :param connector_id: The connector_id of this DeleteSinkTaskRequest.
        :type connector_id: str
        """
        self._connector_id = connector_id

    @property
    def task_id(self):
        """Gets the task_id of this DeleteSinkTaskRequest.

        转储任务ID。

        :return: The task_id of this DeleteSinkTaskRequest.
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this DeleteSinkTaskRequest.

        转储任务ID。

        :param task_id: The task_id of this DeleteSinkTaskRequest.
        :type task_id: str
        """
        self._task_id = task_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteSinkTaskRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
